@@ -70,7 +70,8 @@
             im-normalize
             im-normalize-channel
             im-scrap
-            im-particles))
+            im-particles
+            im-particle-clean))
 
 
 #;(g-export )
@@ -129,14 +130,15 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
              ((r g b a)
               (let ((a-norm (im-normalize-channel a width height)))
                 (list width height 3
-                      (par-map (lambda (vals)
-                                 (match vals
-                                   ((c bg)
-                                    (im-rgba-channel->rgb-channel c width height
-                                                                  a-norm #:bg bg))))
-                          (list (list r bg-r)
-                                (list g bg-g)
-                                (list b bg-b))))))))
+                      (let ((map-proc (if (%use-par-map) par-map map)))
+                        (map-proc (lambda (vals)
+                                    (match vals
+                                      ((c bg)
+                                       (im-rgba-channel->rgb-channel c width height
+                                                                     a-norm #:bg bg))))
+                                  (list (list r bg-r)
+                                        (list g bg-g)
+                                        (list b bg-b)))))))))
           (else
            (error "Not an RGBA image."))))))
     (else
@@ -201,7 +203,8 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
   (match image
     ((width height n-chan idata)
      (list width height n-chan
-	   (let ((map-proc (if (> n-chan 1) par-map map)))
+           (let ((map-proc (if (and (> n-chan 1)
+                                    (%use-par-map)) par-map map)))
 	     (map-proc (lambda (channel)
 			 (im-add-channel channel width height val))
 	       idata))))))
@@ -220,7 +223,8 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
   (match image
     ((width height n-chan idata)
      (list width height n-chan
-	   (let ((map-proc (if (> n-chan 1) par-map map)))
+           (let ((map-proc (if (and (> n-chan 1)
+                                    (%use-par-map)) par-map map)))
 	     (map-proc (lambda (channel)
 			 (im-substract-channel channel width height val))
 	       idata))))))
@@ -239,7 +243,8 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
   (match image
     ((width height n-chan idata)
      (list width height n-chan
-	   (let ((map-proc (if (> n-chan 1) par-map map)))
+           (let ((map-proc (if (and (> n-chan 1)
+                                    (%use-par-map)) par-map map)))
 	     (map-proc (lambda (channel)
 			 (im-multiply-channel channel width height val))
 	       idata))))))
@@ -258,7 +263,8 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
   (match image
     ((width height n-chan idata)
      (list width height n-chan
-	   (let ((map-proc (if (> n-chan 1) par-map map)))
+           (let ((map-proc (if (and (> n-chan 1)
+                                    (%use-par-map)) par-map map)))
 	     (map-proc (lambda (channel)
 			 (im-divide-channel channel width height val))
 	       idata))))))
@@ -284,7 +290,8 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
 		  (n-cell (* width height))
 		  (c-channels (im-collect (map im-rgb->grey rest) 'grey)))
 	      (list width height n-chan
-		    (let ((map-proc (if (> n-chan 1) par-map map)))
+                    (let ((map-proc (if (and (> n-chan 1)
+                                             (%use-par-map)) par-map map)))
 		      (map-proc
 		       (lambda (channel)
 			 (do ((i 0
@@ -308,7 +315,8 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
 		  (n-cell (* width height))
 		  (c-channels (im-collect (map im-rgb->grey rest) 'grey)))
 	      (list width height n-chan
-		    (let ((map-proc (if (> n-chan 1) par-map map)))
+                    (let ((map-proc (if (and (> n-chan 1)
+                                             (%use-par-map)) par-map map)))
 		      (map-proc
 		       (lambda (channel)
 			 (do ((i 0
@@ -326,7 +334,8 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
   (match image
     ((width height n-chan idata)
      (list width height n-chan
-	   (let ((map-proc (if (> n-chan 1) par-map map)))
+           (let ((map-proc (if (and (> n-chan 1)
+                                    (%use-par-map)) par-map map)))
 	     (map-proc
 	      (lambda (channel)
 		(f32vector-complement channel))
@@ -334,27 +343,30 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
 
 (define (im-min image)
     (match image
-    ((width height n-chan idata)
-     (let ((map-proc (if (> n-chan 1) par-map map)))
-       (map-proc
-	(lambda (channel)
-	  (f32vector-min channel))
-	idata)))))
+      ((width height n-chan idata)
+       (let ((map-proc (if (and (> n-chan 1)
+                                (%use-par-map)) par-map map)))
+         (map-proc
+          (lambda (channel)
+            (f32vector-min channel))
+          idata)))))
 
 (define (im-max image)
     (match image
-    ((width height n-chan idata)
-     (let ((map-proc (if (> n-chan 1) par-map map)))
-       (map-proc
-	(lambda (channel)
-	  (f32vector-max channel))
-	idata)))))
+      ((width height n-chan idata)
+       (let ((map-proc (if (and (> n-chan 1)
+                                (%use-par-map)) par-map map)))
+         (map-proc
+          (lambda (channel)
+            (f32vector-max channel))
+          idata)))))
 
 (define (im-transpose image)
   (match image
     ((width height n-chan idata)
      (list height width n-chan
-	   (let ((map-proc (if (> n-chan 1) par-map map)))
+           (let ((map-proc (if (and (> n-chan 1)
+                                    (%use-par-map)) par-map map)))
 	     (map-proc (lambda (channel)
 			 (im-transpose-channel channel width height))
 	       idata))))))
@@ -376,7 +388,8 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
   (match image
     ((width height n-chan idata)
      (list height width n-chan
-	   (let ((map-proc (if (> n-chan 1) par-map map)))
+           (let ((map-proc (if (and (> n-chan 1)
+                                    (%use-par-map)) par-map map)))
 	     (map-proc (lambda (channel)
 			 (im-normalize-channel channel width height))
 	       idata))))))
@@ -464,9 +477,48 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
                             (f32vector-ref channel i)))))
     to))
 
-(define (im-particles image properties)
-  (par-map (lambda (prop)
-             (match prop
-               ((area left top right bottom . rest)
-                (im-crop image left top (+ right 1) (+ bottom 1)))))
-      properties))
+(define* (im-particles image properties #:key (clean #t))
+  (let ((map-proc (if (%use-par-map) par-map map)))
+    (map-proc (lambda (prop)
+                (match prop
+                  ((area left top right bottom . rest)
+                   (parameterize ((%use-par-map #f))
+                     (let ((particle (im-crop image left top (+ right 1) (+ bottom 1))))
+                       (if clean
+                           (im-particle-clean particle)
+                           particle))))))
+              (cdr properties))))
+
+(define (im-particle-clean particle)
+  (let* ((binary? (im-binary? particle))
+         (binary (if binary? particle (im-threshold particle 1.0)))
+         (cleaned (match binary
+                    ((width height n-chan idata)
+                     (receive (label-im n-label)
+                         (im-label binary)
+                       (let* ((r (- width 1))
+                              (b (- height 1))
+                              (l-channel (im-channel label-im 0))
+                              (n-cel (* width height))
+                              (to-remove (fold (lambda (prop i prev)
+                                                 (match prop
+                                                   ((size left top right bottom . rest)
+                                                    (if (or (not (= left 0))
+                                                            (not (= top 0))
+                                                            (not (= right r))
+                                                            (not (= bottom b)))
+                                                        (cons i prev)
+                                                        prev))))
+                                               '()
+                                               (im-properties binary label-im #:n-label n-label)
+                                               (iota (+ n-label 1))))
+                              (cache (scrap-cache to-remove n-label)))
+                         (do ((i 0
+                                 (+ i 1)))
+                             ((= i n-cel)
+                              (list width height n-chan (list l-channel)))
+                           (let ((val
+                                  (float->int (f32vector-ref l-channel i))))
+                             (when (vector-ref cache val)
+                               (f32vector-set! l-channel i 0.0))))))))))
+    (if binary? cleaned (im-and particle cleaned))))
