@@ -66,7 +66,8 @@
   (match image
     ((width height n-chan idata)
      (list width height n-chan
-	   (let ((map-proc (if (> n-chan 1) par-map map)))
+           (let ((map-proc (if (and (> n-chan 1)
+                                    (%use-par-map)) par-map map)))
 	     (map-proc (lambda (channel)
 			 (im-disc-erode-channel channel width height radius))
 		       idata))))))
@@ -82,7 +83,8 @@
   (match image
     ((width height n-chan idata)
      (list width height n-chan
-	   (let ((map-proc (if (> n-chan 1) par-map map)))
+           (let ((map-proc (if (and (> n-chan 1)
+                                    (%use-par-map)) par-map map)))
 	     (map-proc (lambda (channel)
 			 (im-disc-dilate-channel channel width height radius))
 		       idata))))))
