@@ -111,10 +111,11 @@
   (match image
     ((width height n-chan idata)
      (list width height n-chan
-	   (let ((map-proc (if (> n-chan 1) par-map map)))
-	     (map-proc (lambda (channel)
-			 (im-watershed-channel channel width height))
-		       idata))))))
+           (let ((map-proc (if (and (> n-chan 1)
+                                    (%use-par-map)) par-map map)))
+             (map-proc (lambda (channel)
+                         (im-watershed-channel channel width height))
+                       idata))))))
 
 #;(define (im-watershed-channel channel width height)
   (let ((to (im-make-channel width height)))
